.. _expr_funcs:


Index Expression Functions
=============================

.. currentmodule:: pytaco

.. autosummary::
   :toctree: functions

   cast
   remainder
   abs
   pow
   square
   cube
   sqrt
   cube_root
   exp
   log
   log10
   sin
   cos
   tan
   asin
   acos
   atan
   atan2
   sinh
   cosh
   tanh
   asinh
   acosh
   atanh
   logical_not
   gt
   lt
   ge
   le
   eq
   ne
   max
   min
   heaviside
   sum
   add
   mul
   sub
   div